<?php
namespace Controller;

use Exception\CustomException;
use Zeedhi\Framework\Controller\Simple;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Util\Utilities;
use Util\Messages;
use Util\InstanceProvider;

class ZmartOperator extends Simple
{
	public function getZmartOperatorsByCdCliente(Request\Filter $request, Response $response){
        $conditions = $request->getFilterCriteria()->getConditions();
		$nrorg = $this->getNrorg();
        $page           = $request->getFilterCriteria()->getPage();
        $pageSize       = $request->getFilterCriteria()->getPageSize();
        $orderBy        = $request->getFilterCriteria()->getOrderBy();
        $data = InstanceProvider::getService()->getZmartIntegration()->getZmartOperatorByNrorg($nrorg, $conditions, $page, $pageSize, $orderBy);
        $response->addDataSet(new DataSet('getZmartOperatorsByCdCliente', $data ?: [] ));
    }

    public function requestNewZmartPassword(Request\Row $request, Response $response){
        $row = $request->getRow();
        $email = $row['DSEMAILOPER'];
        $data = InstanceProvider::getService()->getZmartIntegration()->requestNewZmartPassword($email);
        $response->addDataSet(new DataSet('requestNewZmartPassword', $data ?: [] ));
	}

	public function saveOperadorEmail(Request\Row $request, Response $response){
		$row = $request->getRow();
		$email = $row['DSEMAILOPER'];
        $cdoperador = $row['CDOPERADOR'];
        $nrorg =  $this->getNrorg();
        $cdoperultatu = Utilities::getEnvironment()->getCurrentUserId();
		$data = InstanceProvider::getService()->getZmartIntegration()->saveOperadorEmail($cdoperador,$email,$nrorg,$cdoperultatu,$nrorg);
		$response->addDataSet(new DataSet('saveOperadorEmail', $data ?: [] ));
    }
    
    protected function getNrorg(){
        $query = <<<SQL
        SELECT ORG.NRORG
        FROM CLIENTE C
        JOIN ORGANIZACAO ORG ON ORG.NRPARCNEGOCIO = C.NRPARCNEGOCIO
        WHERE C.CDCLIENTE = :CDCLIENTE
        AND C.IDCLIEATIV = 'S'
SQL;
        $params = array(
            "CDCLIENTE" => Utilities::getEnvironment()->getCurrentCdCliente()
        );
        $entityManager = InstanceProvider::getEntityManager();

        $result = $entityManager->getConnection()->fetchAll($query, $params);
        return !empty($result) ? $result[0]["NRORG"] : 0;
    }
}